require 'rails_helper'

RSpec.describe Hermes::Nud, type: :model do
  context 'for structural tests' do
    let(:applicant) { create(:applicant) }
    let(:request) { create(:housing_request, main_applicant: applicant) }

    it 'has a valid factory' do
      expect(FactoryBot.build(:nud, housing_request: request)).to be_valid
    end
  end

  context 'with basic objects' do
    let!(:applicant1) { create(:applicant) }
    let!(:request1) { create(:housing_request, main_applicant: applicant1) }
    let!(:nud1) do
      create(
        :nud,
        housing_request: request1,
        department: '12',
        creation_date: '2016-23-14T14:53:22'
      )
    end
    let!(:nud2) do
      create(
        :nud,
        housing_request: request1,
        department: '12',
        creation_date: '2013-23-14T14:53:22'
      )
    end
    let!(:nud3) do
      create(
        :nud,
        housing_request: request1,
        department: '14',
        creation_date: '2017-23-14T14:53:22'
      )
    end

    describe 'side effects are correct' do
      it 'should has valide nud_creations for request1' do
        nud_creations = request1.reload.nud_creations
        { '12' => nud2, '14' => nud3 }.each do |key, nud|
          expect(nud_creations[key]).to(
            eq(nud.reload.creation_date)
          )
        end
      end
    end
    describe 'create nud ' do
      it 'trigger sopra flux' do
        after_create_res = nud3.after_create_actions()
        expect(after_create_res[:exectuted]).to eq(true)
      end
    
    end
  end
end
